"""
Cost catalog content
SPDX - License - Identifier: LGPL - 3.0 - or -later
Copyright © 2022 Concordia CERC group
Project Coder Atiya atiya.atiya@mail.concordia.ca
Code contributors: Pilar Monsalvete Alvarez de Uribarri pilar.monsalvete@concordia.ca
"""


class Content:
  """
  Content class
  """
  def __init__(self, archetypes):
    self._archetypes = archetypes

  @property
  def archetypes(self):
    """
    All archetypes in the catalog
    """
    return self._archetypes

  def to_dictionary(self):
    """Class content to dictionary"""
    _archetypes = []
    for _archetype in self.archetypes:
      _archetypes.append(_archetype.to_dictionary())
    content = {'Archetypes': _archetypes}

    return content

  def __str__(self):
    """Print content"""
    _archetypes = []
    for _archetype in self.archetypes:
      _archetypes.append(_archetype.to_dictionary())
    content = {'Archetypes': _archetypes}

    return str(content)



"""
Dictionaries module for hub usage to Hft usage
SPDX - License - Identifier: LGPL - 3.0 - or -later
Copyright © 2022 Concordia CERC group
Project Coder Guille Gutierrez Guillermo.GutierrezMorote@concordia.ca
"""

import hub.helpers.constants as cte


class HubUsageToHftUsage:
  """
  Hub usage to hft usage class
  """

  def __init__(self):
    self._dictionary = {
      cte.RESIDENTIAL: 'residential',
      cte.SINGLE_FAMILY_HOUSE: 'single family house',
      cte.MULTI_FAMILY_HOUSE: 'multifamily house',
      cte.ROW_HOUSE: 'single family house',
      cte.MID_RISE_APARTMENT: 'multifamily house',
      cte.HIGH_RISE_APARTMENT: 'multifamily house',
      cte.OFFICE_AND_ADMINISTRATION: 'office and administration',
      cte.SMALL_OFFICE: 'office and administration',
      cte.MEDIUM_OFFICE: 'office and administration',
      cte.LARGE_OFFICE: 'office and administration',
      cte.COURTHOUSE: 'office and administration',
      cte.FIRE_STATION: 'office and administration',
      cte.PENITENTIARY: 'school with shower',
      cte.POLICE_STATION: 'office and administration',
      cte.POST_OFFICE: 'office and administration',
      cte.LIBRARY: 'office and administration',
      cte.EDUCATION: 'education',
      cte.PRIMARY_SCHOOL: 'school without shower',
      cte.PRIMARY_SCHOOL_WITH_SHOWER: 'school with shower',
      cte.SECONDARY_SCHOOL: 'education',
      cte.UNIVERSITY: 'education',
      cte.LABORATORY_AND_RESEARCH_CENTER: 'laboratory and research centers',
      cte.STAND_ALONE_RETAIL: 'retail',
      cte.HOSPITAL: 'health care',
      cte.OUT_PATIENT_HEALTH_CARE: 'health care',
      cte.HEALTH_CARE: 'health care',
      cte.RETIREMENT_HOME_OR_ORPHANAGE: 'Home for the aged or orphanage',
      cte.COMMERCIAL: 'retail',
      cte.STRIP_MALL: 'retail',
      cte.SUPERMARKET: 'retail shop / refrigerated food',
      cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD: 'retail',
      cte.RETAIL_SHOP_WITH_REFRIGERATED_FOOD: 'retail shop / refrigerated food',
      cte.RESTAURANT: 'restaurant',
      cte.QUICK_SERVICE_RESTAURANT: 'restaurant',
      cte.FULL_SERVICE_RESTAURANT: 'restaurant',
      cte.HOTEL: 'hotel',
      cte.HOTEL_MEDIUM_CLASS: 'hotel (Medium-class)',
      cte.SMALL_HOTEL: 'hotel',
      cte.LARGE_HOTEL: 'hotel',
      cte.DORMITORY: 'dormitory',
      cte.EVENT_LOCATION: 'event location',
      cte.CONVENTION_CENTER: 'event location',
      cte.HALL: 'hall',
      cte.GREEN_HOUSE: 'green house',
      cte.INDUSTRY: 'industry',
      cte.WORKSHOP: 'industry',
      cte.WAREHOUSE: 'industry',
      cte.WAREHOUSE_REFRIGERATED: 'industry',
      cte.SPORTS_LOCATION: 'sport location',
      cte.SPORTS_ARENA: 'sport location',
      cte.GYMNASIUM: 'sport location',
      cte.MOTION_PICTURE_THEATRE: 'event location',
      cte.MUSEUM: 'event location',
      cte.PERFORMING_ARTS_THEATRE: 'event location',
      cte.TRANSPORTATION: 'n/a',
      cte.AUTOMOTIVE_FACILITY: 'n/a',
      cte.PARKING_GARAGE: 'n/a',
      cte.RELIGIOUS: 'event location',
      cte.NON_HEATED: 'non-heated',
      cte.DATACENTER: 'n/a',
      cte.FARM: 'n/a'
    }

  @property
  def dictionary(self) -> dict:
    """
    Get the dictionary
    :return: {}
    """
    return self._dictionary



"""
Dictionaries module for hub usage to NRCAN usage
SPDX - License - Identifier: LGPL - 3.0 - or -later
Copyright © 2022 Concordia CERC group
Project Coder Guille Gutierrez Guillermo.GutierrezMorote@concordia.ca
"""

import hub.helpers.constants as cte


class HubUsageToNrcanUsage:
  """
  Hub usage to nrcan usage class
  """

  def __init__(self):
    self._dictionary = {
      cte.RESIDENTIAL: 'Multi-unit residential building',
      cte.SINGLE_FAMILY_HOUSE: 'Multi-unit residential building',
      cte.MULTI_FAMILY_HOUSE: 'Multi-unit residential building',
      cte.ROW_HOUSE: 'Multi-unit residential building',
      cte.MID_RISE_APARTMENT: 'Multi-unit residential building',
      cte.HIGH_RISE_APARTMENT: 'Multi-unit residential building',
      cte.OFFICE_AND_ADMINISTRATION: 'Office',
      cte.SMALL_OFFICE: 'Office',
      cte.MEDIUM_OFFICE: 'Office',
      cte.LARGE_OFFICE: 'Office',
      cte.COURTHOUSE: 'Courthouse',
      cte.FIRE_STATION: 'Fire station',
      cte.PENITENTIARY: 'Penitentiary',
      cte.POLICE_STATION: 'Police station',
      cte.POST_OFFICE: 'Post office',
      cte.LIBRARY: 'Library',
      cte.EDUCATION: 'School/university',
      cte.PRIMARY_SCHOOL: 'School/university',
      cte.PRIMARY_SCHOOL_WITH_SHOWER: 'School/university',
      cte.SECONDARY_SCHOOL: 'School/university',
      cte.UNIVERSITY: 'School/university',
      cte.LABORATORY_AND_RESEARCH_CENTER: 'School/university',
      cte.STAND_ALONE_RETAIL: 'Retail area',
      cte.HOSPITAL: 'Hospital',
      cte.OUT_PATIENT_HEALTH_CARE: 'Health care clinic',
      cte.HEALTH_CARE: 'Health care clinic',
      cte.RETIREMENT_HOME_OR_ORPHANAGE: 'Health care clinic',
      cte.COMMERCIAL: 'Retail area',
      cte.STRIP_MALL: 'Retail area',
      cte.SUPERMARKET: 'Retail area',
      cte.RETAIL_SHOP_WITHOUT_REFRIGERATED_FOOD: 'Retail area',
      cte.RETAIL_SHOP_WITH_REFRIGERATED_FOOD: 'Retail area',
      cte.RESTAURANT: 'Dining - bar lounge/leisure',
      cte.QUICK_SERVICE_RESTAURANT: 'Dining - cafeteria/fast food',
      cte.FULL_SERVICE_RESTAURANT: 'Dining - bar lounge/leisure',
      cte.HOTEL: 'Hotel/Motel',
      cte.HOTEL_MEDIUM_CLASS: 'Hotel/Motel',
      cte.SMALL_HOTEL: 'Hotel/Motel',
      cte.LARGE_HOTEL: 'Hotel/Motel',
      cte.DORMITORY: 'Dormitory',
      cte.EVENT_LOCATION: 'Convention centre',
      cte.CONVENTION_CENTER: 'Convention centre',
      cte.HALL: 'Town hall',
      cte.GREEN_HOUSE: 'n/a',
      cte.INDUSTRY: 'Manufacturing facility',
      cte.WORKSHOP: 'Workshop',
      cte.WAREHOUSE: 'Warehouse',
      cte.WAREHOUSE_REFRIGERATED: 'Warehouse',
      cte.SPORTS_LOCATION: 'Exercise centre',
      cte.SPORTS_ARENA: 'Sports arena',
      cte.GYMNASIUM: 'Gymnasium',
      cte.MOTION_PICTURE_THEATRE: 'Motion picture theatre',
      cte.MUSEUM: 'Museum',
      cte.PERFORMING_ARTS_THEATRE: 'Performing arts theatre',
      cte.TRANSPORTATION: 'Transportation facility',
      cte.AUTOMOTIVE_FACILITY: 'Automotive facility',
      cte.PARKING_GARAGE: 'Storage garage',
      cte.RELIGIOUS: 'Religious building',
      cte.NON_HEATED: 'n/a',
      cte.DATACENTER: 'n/a',
      cte.FARM: 'n/a'
    }

  @property
  def dictionary(self) -> dict:
    """
    Get the dictionary
    :return: {}
    """
    return self._dictionary
